==> eiffelstudio-18.11.10.2592.tar: F_code/C13/xm629.c <==
/*
 * Code for class XM_XPATH_HOMOGENEOUS_NODE_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm629.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_HOMOGENEOUS_NODE_CHECKER}.make */
void F1492_12477 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {XM_XPATH_HOMOGENEOUS_NODE_CHECKER}.last_node_iterator */
EIF_REFERENCE F1492_12478 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XM_XPATH_HOMOGENEOUS_NODE_CHECKER}.map_nodes */
void F1492_12479 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLIU(6);
	
	RTGC;
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R13091[Dtype(arg1)-1743])(RTCW(arg1));
	if ((EIF_BOOLEAN) !tb1) {
		tr1 = RTLNS(eif_new_type(1590, 0x00).id, 1590, _OBJSIZ_2_1_0_1_0_0_0_0_);
		tr2 = RTMS_EX_H("Path expressions may not mix atomic values and nodes",52,422009203);
		tr3 = RTOSCF(9624,F1200_9624,(Current));
		tr4 = RTMS_EX_H("XPTY0018",8,457776184);
		F1591_13697(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 2L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1620, 0x00).id, 1620, _OBJSIZ_4_2_0_1_0_0_0_0_);
		tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13109[Dtype(arg1)-1743])(RTCW(arg1));
		F1598_13793(RTCW(tr1), tr2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

void EIF_Minit629 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C13/xm629.c <==
/*
 * Code for class XM_XPATH_HOMOGENEOUS_NODE_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "xm629.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {XM_XPATH_HOMOGENEOUS_NODE_CHECKER}.make */
void F1498_12518 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {XM_XPATH_HOMOGENEOUS_NODE_CHECKER}.last_node_iterator */
EIF_REFERENCE F1498_12519 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {XM_XPATH_HOMOGENEOUS_NODE_CHECKER}.map_nodes */
void F1498_12520 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,tr3);
	RTLR(5,tr4);
	RTLIU(6);
	
	RTGC;
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R13122[Dtype(RTCW(arg1))-1751])(arg1);
	if ((EIF_BOOLEAN) !tb1) {
		tr1 = RTLNS(eif_new_type(1597, 0x01).id, 1597, _OBJSIZ_2_1_0_1_0_0_0_0_);
		tr2 = RTMS_EX_H("Path expressions may not mix atomic values and nodes",52,422009203);
		tr3 = RTOSCF(9655,F1200_9655, (Current));
		tr4 = RTMS_EX_H("XPTY0018",8,457776184);
		F1598_13738(RTCW(tr1), tr2, tr3, tr4, ((EIF_INTEGER_32) 2L));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		tr1 = RTLNS(eif_new_type(1627, 0x01).id, 1627, _OBJSIZ_4_2_0_1_0_0_0_0_);
		tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R13140[Dtype(RTCW(arg1))-1751])(arg1);
		F1605_13834(RTCW(tr1), tr2);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

void EIF_Minit629 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
